==> orangehrm-3.3.2.txz: usr/local/www/orangehrm/symfony/plugins/orangehrmLeavePlugin/test/model/service/LeaveConfigurationServiceTest.php <==
<?php

/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 *
 */

/**
 * Test class for LeaveConfigurationService
 * @group Leave
 */
class LeaveConfigurationServiceTest extends PHPUnit_Framework_TestCase {

    private $service;

    /**
     * Set up method
     */
    protected function setUp() {
        $this->service = new LeaveConfigurationService();
    }
    
    public function testGetLeaveEntitlementConsumptionStrategy() {
        
        $strategy = "FIFO";
        $mockDao = $this->getMock('ConfigDao', array('getValue'));
        $mockDao->expects($this->once())
                    ->method('getValue')
                    ->with(LeaveConfigurationService::KEY_LEAVE_ENTITLEMENT_CONSUMPTION_STRATEGY)
                    ->will($this->returnValue($strategy)); 
        
        $this->service->setConfigDao($mockDao);
        
        $this->assertEquals($strategy, $this->service->getLeaveEntitlementConsumptionStrategy());
    }
    
    public function testGetWorkScheduleImplementation() {
        $implementation = "Basic";
        $mockDao = $this->getMock('ConfigDao', array('getValue'));
        $mockDao->expects($this->once())
                    ->method('getValue')
                    ->with(LeaveConfigurationService::KEY_LEAVE_WORK_SCHEDULE_IMPLEMENTATION)
                    ->will($this->returnValue($implementation)); 
        
        $this->service->setConfigDao($mockDao);
        
        $this->assertEquals($implementation, $this->service->getWorkScheduleImplementation());        
    }
    
}

==> orangehrm-4.7.txz: usr/local/www/orangehrm/symfony/plugins/orangehrmLeavePlugin/test/model/service/LeaveConfigurationServiceTest.php <==
<?php

/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 *
 */

/**
 * Test class for LeaveConfigurationService
 * @group Leave
 */
class LeaveConfigurationServiceTest extends PHPUnit_Framework_TestCase {

    private $service;

    /**
     * Set up method
     */
    protected function setUp() {
        $this->service = new LeaveConfigurationService();
    }
    
    public function testGetLeaveEntitlementConsumptionStrategy() {
        
        $strategy = "FIFO";
        $mockDao = $this->getMockBuilder('ConfigDao')
			->setMethods( array('getValue'))
			->getMock();
        $mockDao->expects($this->once())
                    ->method('getValue')
                    ->with(LeaveConfigurationService::KEY_LEAVE_ENTITLEMENT_CONSUMPTION_STRATEGY)
                    ->will($this->returnValue($strategy)); 
        
        $this->service->setConfigDao($mockDao);
        
        $this->assertEquals($strategy, $this->service->getLeaveEntitlementConsumptionStrategy());
    }
    
    public function testGetWorkScheduleImplementation() {
        $implementation = "Basic";
        $mockDao = $this->getMockBuilder('ConfigDao')
			->setMethods( array('getValue'))
			->getMock();
        $mockDao->expects($this->once())
                    ->method('getValue')
                    ->with(LeaveConfigurationService::KEY_LEAVE_WORK_SCHEDULE_IMPLEMENTATION)
                    ->will($this->returnValue($implementation)); 
        
        $this->service->setConfigDao($mockDao);
        
        $this->assertEquals($implementation, $this->service->getWorkScheduleImplementation());        
    }
    
}
